@@ -61,12 +61,8 @@ update_own_avatar_sha1 (GabbleConnection *conn,
 
   if (!_gabble_connection_signal_own_presence (conn, &error))
     {
-      if (out_error == NULL)
-        {
-          DEBUG ("failed to signal changed avatar sha1 to the server: %s",
-              error->message);
-          g_error_free (error);
-        }
+      DEBUG ("failed to signal changed avatar sha1 to the server: %s",
+          error->message);
 
       g_propagate_error (out_error, error);
 
@@ -288,6 +284,8 @@ _got_self_avatar_for_get_known_avatar_tokens (GObject *obj,
 
   g_signal_handler_disconnect (obj, context->signal_conn);
 
+  g_assert (base->self_handle != 0);
+
   g_hash_table_insert (context->ret, GUINT_TO_POINTER (base->self_handle),
       g_strdup (sha1));
 
@@ -300,9 +298,9 @@ _got_self_avatar_for_get_known_avatar_tokens (GObject *obj,
 
 
 /**
- * gabble_connection_get_avatar_tokens
+ * gabble_connection_get_known_avatar_tokens
  *
- * Implements D-Bus method GetAvatarTokens
+ * Implements D-Bus method GetKnownAvatarTokens
  * on interface org.freedesktop.Telepathy.Connection.Interface.Avatars
  *
  * @context: The D-Bus invocation context to use to return values
