@@ -390,12 +390,10 @@ gabble_media_channel_set_property (GObject     *object,
       g_free (priv->object_path);
       priv->object_path = g_value_dup_string (value);
       break;
-    case PROP_HANDLE:
-      /* this property is writable in the interface, but not actually
-       * meaningfully changable on this channel, so we do nothing */
-      break;
     case PROP_HANDLE_TYPE:
-      /* this property is writable in the interface, but not actually
+    case PROP_HANDLE:
+    case PROP_CHANNEL_TYPE:
+      /* these properties are writable in the interface, but not actually
        * meaningfully changable on this channel, so we do nothing */
       break;
     case PROP_CONNECTION:
